<?php
/**
 * Theme homepage options.
 *
 * @package fad
 * @since 3.0.0
 */

/**
 * Registers the customizer homepage options.
 *
 * @param  WP_Customize_Manager $wp_customize The WordPress customizer manager instance.
 * @return void
 */
function fad_customize_register_homepage( $wp_customize ) {
	/**
	 * == Homepage ==
	 *
	 * Add a homepage settings panel.
	 */
	$wp_customize->add_panel(
		'fad_home',
		array(
			'priority' => 120,
			'title'    => esc_html__( 'Homepage', 'fad' ),
		)
	);

	/**
	 * Move the homepage settings section to the homepage settings panel.
	 */
	$static_front_page_section        = $wp_customize->get_section( 'static_front_page' );
	$static_front_page_section->panel = 'fad_home';
	$static_front_page_section->title = esc_html__( 'Settings', 'fad' );

	/**
	 * == Recent Posts ==
	 *
	 * Add fields in recent posts section.
	 * Add option to set the overlay color.
	 *
	 * Add recent posts section.
	 */
	$wp_customize->add_section(
		'fad_home_recent_posts',
		array(
			'active_callback' => 'fad_is_homepage',
			'panel'           => 'fad_home',
			'title'           => esc_html__( 'Recent Posts', 'fad' ),
			'priority'        => 1010,
		)
	);

	/**
	 * Add option to enable/disable recent posts.
	 */
	$wp_customize->add_setting(
		'fad_home_show_recent_posts',
		array(
			'default'           => true,
			'sanitize_callback' => 'fad_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'fad_home_show_recent_posts',
			array(
				'label'   => esc_html__( 'Show recent posts?', 'fad' ),
				'section' => 'fad_home_recent_posts',
				'type'    => 'checkbox',
			)
		)
	);

	/**
	 * Adds option to show recent post title and description.
	 */
	$wp_customize->add_setting(
		'fad_show_recent_posts_title_desc',
		array(
			'default'           => false,
			'sanitize_callback' => 'fad_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'fad_show_recent_posts_title_desc',
			array(
				'label'   => esc_html__( 'Show title and description?', 'fad' ),
				'section' => 'fad_home_recent_posts',
				'type'    => 'checkbox',
			)
		)
	);

	/**
	 * Add option to set the title of recent posts section.
	 */
	$wp_customize->add_setting(
		'fad_home_recent_posts_title',
		array(
			'default'           => esc_html__( 'Recent Posts', 'fad' ),
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'fad_home_recent_posts_title',
			array(
				'active_callback' => 'fad_has_show_recent_posts_title_desc',
				'label'           => esc_html__( 'Title', 'fad' ),
				'section'         => 'fad_home_recent_posts',
				'type'            => 'text',
			)
		)
	);

	/**
	 * Add option to set the description of recent posts section.
	 */
	$wp_customize->add_setting(
		'fad_home_recent_posts_description',
		array(
			'default'           => '',
			'sanitize_callback' => 'wp_kses_post',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'fad_home_recent_posts_description',
			array(
				'active_callback' => 'fad_has_show_recent_posts_title_desc',
				'label'           => esc_html__( 'Description', 'fad' ),
				'section'         => 'fad_home_recent_posts',
				'type'            => 'textarea',
			)
		)
	);

	/**
	 * Add option to upload background image
	 */
	$wp_customize->add_setting(
		'fad_home_recent_posts_bg_image',
		array(
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Cropped_Image_Control(
			$wp_customize,
			'fad_home_recent_posts_bg_image',
			array(
				'label'       => esc_html__( 'Background image', 'fad' ),
				'description' => esc_html__( 'Increase or decrease background image visibility by changing the Overlay Opacity.', 'fad' ),
				'section'     => 'fad_home_recent_posts',
				'flex-height' => true,
				'flex-width'  => true,
				'height'      => 1000, // pixels.
				'width'       => 1500, // pixels.
			)
		)
	);

	$wp_customize->add_setting(
		'fad_home_recent_posts_overlay_color',
		array(
			'default'           => '#EAEAEA',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'fad_home_recent_posts_overlay_color',
			array(
				'label'    => esc_html__( 'Overlay Color', 'fad' ),
				'section'  => 'fad_home_recent_posts',
				'settings' => 'fad_home_recent_posts_overlay_color',
			)
		)
	);

	/**
	* Add option to set the opacity.
	*/
	$wp_customize->add_setting(
		'fad_home_recent_posts_overlay_opacity',
		array(
			'default'           => 1,
			'sanitize_callback' => 'fad_sanitize_opacity',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'fad_home_recent_posts_overlay_opacity',
			array(
				'label'       => esc_html__( 'Overlay Opacity', 'fad' ),
				'section'     => 'fad_home_recent_posts',
				'type'        => 'range',
				'input_attrs' => array(
					'min'  => '0.1',
					'max'  => '1',
					'step' => '0.1',
				),
			)
		)
	);
}
add_action( 'customize_register', 'fad_customize_register_homepage' );

/**
 * Checks if the current page is:
 * - the front page
 * - and has the free or premium homepage template.
 *
 * @return boolean true if the above criteria are met, otherwise false.
 */
function fad_is_homepage() {
	return is_front_page() &&
		is_page_template(
			array(
				'templates/homepage.php',
				'templates/homepage-premium.php',
			)
		);
}

/**
 * Checks if the current page is:
 * - the front page
 * - has the free or premium homepage template
 * - citations sidebar is active
 *
 * @return boolean true if the above criteria are met, otherwise false.
 */
function fad_show_homepage_citations() {
	return fad_is_homepage() && is_active_sidebar( 'citations' );
}

/**
 * Sanitizes the overlay opacity.
 *
 * @param int $value to return.
 * @return float The sanitized base line height.
 */
function fad_sanitize_opacity( $value ) {
	if ( ! abs( floatval( $value ) ) ) {
		$value = '0';
	}

	return $value;
}

/**
 * Returns true if show recent posts title and description option is enabled.
 *
 * @return boolean
 */
function fad_has_show_recent_posts_title_desc() {
	$fad_show_recent_posts_title_desc = get_theme_mod( 'fad_show_recent_posts_title_desc', 'default' );
	if ( '1' == $fad_show_recent_posts_title_desc ) {
		return true;
	}

	return false;
}
